Crate fetchr_integrity

Crate fetchr_integrity 

Structs

Checksum

Enums

Algorithm
Hasher
IntegrityError

Functions

compute_checksum
Computes the checksum of a file on disk asynchronously.
verify_file
Verifies that a file matching the specified expected checksum.

Type Aliases

Result