Crate fetchr_integrity
fetchr_
integrity
0.1.0
All Items
Crate Items
Structs
Enums
Functions
Type Aliases
Crate
fetchr_
integrity
Structs

Checksum
Enums

Algorithm
Hasher
Integrity
Error
Functions

compute_
checksum
Computes the checksum of a file on disk asynchronously.
verify_
file
Verifies that a file matching the specified expected checksum.
Type Aliases

Result